@@ -23,7 +23,7 @@ our $NAME = set_name();
 our $HELP = <<'HELP';
 =pod
 
-down [I<count>]
+B<down> [I<count>]
 
 Move the current frame down in the stack trace (to a newer frame). 0
 is the most recent frame. If no count is given, move down 1.
