@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2011, 2012 Rocky Bernstein <rocky@cpan.org>
-use warnings; no warnings 'redefine';
-
+# Copyright (C) 2011, 2012, 2014 Rocky Bernstein <rocky@cpan.org>
+use warnings; use utf8;
 use rlib '../../../..';
 
 package Devel::Trepan::CmdProcessor::Command::Eval;
@@ -64,18 +63,21 @@ by adding the appropriate sigil C<@>, C<%>, or C<$>.
  eval      # Run current source-code line
  eval?     # but strips off leading 'if', 'while', ..
            # from command
- eval@ @ARGV  # Make sure the result saved is an array rather than
-              # an array converted to a scalar.
+ eval@ @ARGV  # Make sure the result printed and saved as an array rather
+              # than as an array converted to a scalar.
  @ @ARG       # Same as above if @ alias is around
- eval% %ENV   # Make sure the result saved is a hash
+ eval% %ENV   # Make sure the result printed/saved as a hash
  use English  # Note this is a statement, not an expression
  use English; # Same as above
  eval$ use English # Error because this is not a valid expression
 
-See also C<set auto eval>. The command can help one predict future execution.
+=head2 See also:
+
+L<C<set auto eval>|Devel::Trepan::CmdProcessor::Command::Set::Auto::Eval>.
 =cut
 HELP
 
+no warnings 'redefine';
 sub complete($$)
 {
     my ($self, $prefix) = @_;
@@ -135,9 +137,7 @@ sub run($$)
                     fix_file_and_line => 1,
         };
         no warnings 'once';
-        # FIXME: 4 below is a magic fixup constant, also found in
-        # DB::finish.  Remove it.
-        $proc->eval($code_to_eval, $opts, 4);
+        $proc->eval($code_to_eval, $opts);
     }
 }
 
