@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2011-2013 Rocky Bernstein <rocky@cpan.org>
-use warnings; no warnings 'redefine';
+# Copyright (C) 2011-2014 Rocky Bernstein <rocky@cpan.org>
+use warnings; use utf8;
 
 use rlib '../../../..';
 
@@ -45,6 +45,8 @@ while C<break> will have less overhead.
 =cut
 HELP
 
+no warnings 'redefine';
+
 # This method runs the command
 sub run($$) {
     my ($self, $args) = @_;
